'use strict';
var aboxWs = (function () {
	var videoSizeSocketURL = {
			default: 'wss://127.0.0.1:31341',
			fallback: 'ws://127.0.0.1:31340'
		},
		playerSocketURL = {
			default: 'wss://127.0.0.1:31351',
			fallback: 'ws://127.0.0.1:31350'
		};

	function startNewPlayer (url) {
		var playerSocket = null,
			videoIsPlaying = false,
			stopCallbacks = [],
			promiseQueue = [],
			open = false;

		function play(url, vol, cb) {
			vol = vol || -1;
			return new Promise(function(resolve, reject) {
				if (!videoIsPlaying) {
					promiseQueue = [];
					stopCallbacks = [];
				}
				stopCallbacks.push(cb);
				promiseQueue.push({ resolve: resolve, reject: reject });
				playerSocket.send('play ' + url + ' ' + vol.toString());
			});
		};

		function init(url, resolve, reject) {
			playerSocket = new WebSocket(url);

			playerSocket.onmessage = function(e) {
				if (e.data === 'play start') {
					videoIsPlaying = true;
					if (promiseQueue.length) {
						promiseQueue.shift().resolve();
					}
				} else if (e.data == 'play fail') {
					if (promiseQueue.length) {
						promiseQueue.shift().reject('Error attempting to play video');
					}
				} else if (e.data === 'play stop' && videoIsPlaying) {
					videoIsPlaying = false;
					var callback = stopCallbacks.shift();
					if (callback) { callback(); }
				}
			};
			playerSocket.onerror = function() {
				if (url !== playerSocketURL.fallback) {
					init(playerSocketURL.fallback, resolve, reject);
					return;
				}
				if (promiseQueue.length) {
					stopCallbacks.shift();
					promiseQueue.shift().reject('Failed to connect to socket');
				}
				reject('Failed to connect to socket');
			};
			playerSocket.onopen = function(a) {
				open = true;
				playerSocket.send('play');
				resolve({ play: play });
			};
			playerSocket.onclose = function() {
				if (open) {
					init(url, resolve, reject);
				}
			};
		};

		return new Promise(function(resolve, reject) {
			return init(url, resolve, reject);
		});
	};

	function setVideoSize(x, y, w, h, url) {
		url = url || videoSizeSocketURL.default;
		var videoSizeSocket = null,
			command = 'vsize ' + x + ' ' + y + ' ' + w + ' ' + h;

		function setSize(target, resolve, reject) {
			videoSizeSocket = new WebSocket(target);
			videoSizeSocket.onopen = function() {
				videoSizeSocket.send(command);
				videoSizeSocket.close();
				resolve();
			};
			videoSizeSocket.onerror = function() {
				if (target !== videoSizeSocketURL.fallback) {
					setSize(videoSizeSocketURL.fallback, resolve, reject);
					return;
				}
				reject('Failed to connect to socket');
			};
		}

		return new Promise(function(resolve, reject) {
			return setSize(url, resolve, reject);
		});
	};

	return {
		setVideoSize: setVideoSize,
		initPlayer: function() {
			return startNewPlayer(playerSocketURL.default);
		}
	}
}());
